@@ -1,9 +1,13 @@
 class Credentials:
 
-    def __init__(self, event):
+    def __init__(self, username, password):
+        self.__username = username
+        self.__password = password
+
+    @classmethod
+    def from_event(cls, event):
         credentials = event.get('credentials')
-        self.__username = credentials['username']
-        self.__password = credentials['password']
+        return cls(credentials['username'], credentials['password'])
 
     def get_username(self):
         return self.__username
