@@ -1,6 +1,7 @@
 import requests
 from requests import auth
 
+from cloud_control_common.cloud_control_exception import CloudControlException
 from cloud_control_common.config import api_urls, context_path, api_version, my_user_path
 
 
@@ -77,9 +78,10 @@ class HttpClient:
 
     def _report_error_status(self, response):
         if response.status_code == 401:
-            raise Exception(
+            raise CloudControlException(
                 'Supplied credentials are incorrect or user is not associated with this geo {0}.'.format
-                (self.geo))
+                (self.geo), response)
         else:
-            raise Exception(
-                'API call to {0} failed with status code {1}'.format(response.request.url, response.status_code))
+            raise CloudControlException(
+                'API call to {0} failed with status code {1}'.format(response.request.url, response.status_code),
+                response)
